==> skrooge-2.1.1.tar.xz: skrooge-2.1.1/skgbasegui/skgsimpleperiodeditdesignerplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * A period editor (qt designer plugin).
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgsimpleperiodeditdesignerplugin.h"

#include <QIcon>

#include <QtPlugin>

#include "skgsimpleperiodedit.h"

SKGSimplePeriodEditDesignerPlugin::SKGSimplePeriodEditDesignerPlugin(QObject* iParent)
    : QObject(iParent)
{
    m_initialized = false;
}

void SKGSimplePeriodEditDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
{
    Q_UNUSED(iCore);
    if (m_initialized) {
        return;
    }

    m_initialized = true;
}

bool SKGSimplePeriodEditDesignerPlugin::isInitialized() const
{
    return m_initialized;
}

QWidget* SKGSimplePeriodEditDesignerPlugin::createWidget(QWidget* iParent)
{
    return new SKGSimplePeriodEdit(iParent);
}

QString SKGSimplePeriodEditDesignerPlugin::name() const
{
    return "SKGSimplePeriodEdit";
}

QString SKGSimplePeriodEditDesignerPlugin::group() const
{
    return "SKG Widgets";
}

QIcon SKGSimplePeriodEditDesignerPlugin::icon() const
{
    return QIcon::fromTheme("quickopen");
}

QString SKGSimplePeriodEditDesignerPlugin::toolTip() const
{
    return "A simple period editor";
}

QString SKGSimplePeriodEditDesignerPlugin::whatsThis() const
{
    return "A simple period editor";
}

bool SKGSimplePeriodEditDesignerPlugin::isContainer() const
{
    return false;
}

QString SKGSimplePeriodEditDesignerPlugin::domXml() const
{
    return "<widget class=\"SKGSimplePeriodEdit\" name=\"SKGSimplePeriodEdit\">\n"
           " <property name=\"geometry\">\n"
           "  <rect>\n"
           "   <x>0</x>\n"
           "   <y>0</y>\n"
           "   <width>100</width>\n"
           "   <height>10</height>\n"
           "  </rect>\n"
           " </property>\n"
           "</widget>\n";
}

QString SKGSimplePeriodEditDesignerPlugin::includeFile() const
{
    return "skgsimpleperiodedit.h";
}

==> skrooge-2.1.91.tar.xz: skrooge-2.1.91/skgbasegui/skgsimpleperiodeditdesignerplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * A period editor (qt designer plugin).
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgsimpleperiodeditdesignerplugin.h"

#include <QtPlugin>

#include "skgsimpleperiodedit.h"
#include "skgservices.h"

SKGSimplePeriodEditDesignerPlugin::SKGSimplePeriodEditDesignerPlugin(QObject* iParent)
    : QObject(iParent)
{
    m_initialized = false;
}

void SKGSimplePeriodEditDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
{
    Q_UNUSED(iCore);
    if (m_initialized) {
        return;
    }

    m_initialized = true;
}

bool SKGSimplePeriodEditDesignerPlugin::isInitialized() const
{
    return m_initialized;
}

QWidget* SKGSimplePeriodEditDesignerPlugin::createWidget(QWidget* iParent)
{
    return new SKGSimplePeriodEdit(iParent);
}

QString SKGSimplePeriodEditDesignerPlugin::name() const
{
    return "SKGSimplePeriodEdit";
}

QString SKGSimplePeriodEditDesignerPlugin::group() const
{
    return "SKG Widgets";
}

QIcon SKGSimplePeriodEditDesignerPlugin::icon() const
{
    return SKGServices::fromTheme("quickopen");
}

QString SKGSimplePeriodEditDesignerPlugin::toolTip() const
{
    return "A simple period editor";
}

QString SKGSimplePeriodEditDesignerPlugin::whatsThis() const
{
    return "A simple period editor";
}

bool SKGSimplePeriodEditDesignerPlugin::isContainer() const
{
    return false;
}

QString SKGSimplePeriodEditDesignerPlugin::domXml() const
{
    return "<widget class=\"SKGSimplePeriodEdit\" name=\"SKGSimplePeriodEdit\">\n"
           " <property name=\"geometry\">\n"
           "  <rect>\n"
           "   <x>0</x>\n"
           "   <y>0</y>\n"
           "   <width>100</width>\n"
           "   <height>10</height>\n"
           "  </rect>\n"
           " </property>\n"
           "</widget>\n";
}

QString SKGSimplePeriodEditDesignerPlugin::includeFile() const
{
    return "skgsimpleperiodedit.h";
}
